@@ -9,7 +9,6 @@ import more_itertools
 from .collection import Collection
 from .feeds import RSSFeed, RSSFeedEngine, RSSFeedItem
 from .page import Page
-from .site import Site
 
 
 class BlogPost(Page):
@@ -89,5 +88,8 @@ class Blog(Collection):
     content_type: typing.Type[BlogPost] = BlogPost
     archive_reverse: bool = True
     has_archive: bool = True
-    feeds = [RSSFeed]
     archive_sort = 'date'
+
+    @property
+    def feeds(self):
+        return [RSSFeed(self)]
