@@ -82,6 +82,10 @@ class Collection:
         if not self.title:
             self.title = self.__class__.__name__
 
+    @property
+    def slug(self):
+        return slugify(self.title)
+
     @property
     def pages(self) -> typing.List[Page]:
         _pages = []
