@@ -28,6 +28,7 @@ class RSSFeedEngine(Engine):
         trim_blocks=True,
     )
 
+
 class RSSFeedItem:
     """
     The Object to be used with an RSS Feed.
@@ -49,7 +50,7 @@ class RSSFeedItem:
        <https://cyber.harvard.edu/rss/rss.html>
     """
 
-    def __init__(self, cls, site_url=""):
+    def __init__(self, cls):
         """
         Parse information from the given class object.
 
@@ -72,8 +73,7 @@ class RSSFeedItem:
 
         self.guid = getattr(cls, "guid", cls.slug)
         logging.debug(vars(cls))
-        route = cls.routes[0]
-        self.link = f"{route}/{cls.slug}"
+        self.link = cls.url
         self.pub_date = cls.date_published
 
 
@@ -86,8 +86,7 @@ class RSSFeed(Page):
     link = ""
     slug = ""
 
-    def __init__(self):
+    def __init__(self, collection):
         super().__init__()
         self.no_index = True
-
-
+        self.items = [item.rss_feed_item for item in collection.pages]
