@@ -5,8 +5,6 @@ import pendulum
 
 from .blog import Blog, BlogPost
 from .feeds import RSSFeedEngine, RSSFeedItem
-from .site import Site
-
 
 class MicroBlogPost(BlogPost):
     """
@@ -27,14 +25,9 @@ class MicroBlogPost(BlogPost):
     def __init__(self, **kwargs):
         """checks published options and accepts the first that is listed"""
         super().__init__(**kwargs)
-        self.slug = pendulum.parse(self.date_published, strict=False).format("YMDHmS")
-        self.title = ""
-        self.url = f"{self.routes[0]}/{self.slug}"
 
-    @property
-    def rss_feed_item(self):
-        feed_item = RSSFeedItem(self)
-        return feed_item
+        self.slug = pendulum.parse(self.date_published, strict=False).format("YMMDDHHmmss")
+        self.title = ""
 
 
 class MicroBlog(Blog):
@@ -44,6 +37,6 @@ class MicroBlog(Blog):
 
     _archive_template = "microblog_archive.html"
     _archive_slug = "all_microblog_posts"
-    page_content_type: typing.Type[MicroBlogPost] = MicroBlogPost
+    content_type: typing.Type[MicroBlogPost] = MicroBlogPost
     _archive_reverse: bool = True
     has_archive = True
