@@ -153,9 +153,12 @@ class Site:
 
     def register_feed(self, feed, collection: Collection) -> None:
         extension = self.rss_engine.extension
-        _feed = feed()
-        _feed.slug = collection.__class__.__name__.lower()
-        _feed.items = [page.rss_feed_item for page in collection.pages]
+        _feed = feed
+        _feed.slug = collection.slug
+
+        for item in _feed.items:
+            logging.warning(item.link)
+
         _feed.title = f"{self.SITE_TITLE} - {_feed.title}"
         _feed.link = f"{self.SITE_URL}/{_feed.slug}{extension}"
 
@@ -168,7 +171,8 @@ class Site:
 
 
     def register_route(self, cls) -> None:
-        self.routes.append(cls())
+        route = cls()
+        self.routes.append(route)
 
 
     def render(self, dry_run: bool = False) -> None:
